<a id="types-aiobotocore-eks"></a>

# types-aiobotocore-eks

[![PyPI - types-aiobotocore-eks](https://img.shields.io/pypi/v/types-aiobotocore-eks.svg?color=blue)](https://pypi.org/project/types-aiobotocore-eks)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-eks.svg?color=blue)](https://pypi.org/project/types-aiobotocore-eks)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-eks?color=blue)](https://pypistats.org/packages/types-aiobotocore-eks)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[aiobotocore.EKS 2.4.2](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks.html#EKS)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.13.0](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[types-aiobotocore](https://pypi.org/project/types-aiobotocore/) page and in
[types-aiobotocore-eks docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_eks/).

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [types-aiobotocore-eks](#types-aiobotocore-eks)
  - [How to install](#how-to-install)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [How it works](#how-it-works)
  - [What's new](#what's-new)
    - [Implemented features](#implemented-features)
    - [Latest changes](#latest-changes)
  - [Versioning](#versioning)
  - [Thank you](#thank-you)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `EKS` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[eks]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[eks]'


# standalone installation
python -m pip install types-aiobotocore-eks
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y types-aiobotocore-eks
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[eks]` in your environment:

```bash
python -m pip install 'types-aiobotocore[eks]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `types-aiobotocore-lite[eks]` in your environment:

```bash
python -m pip install 'types-aiobotocore-lite[eks]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `types-aiobotocore` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `types-aiobotocore` with services you use in your environment:

```bash
python -m pip install 'types-aiobotocore[eks]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed
  `types-aiobotocore`

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `types-aiobotocore[eks]` with services you use in your environment:

```bash
python -m pip install 'types-aiobotocore[eks]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[eks]` in your environment:

```bash
python -m pip install 'types-aiobotocore[eks]'`
```

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `types-aiobotocore[eks]` in your environment:

```bash
python -m pip install 'types-aiobotocore[eks]'
```

Optionally, you can install `types-aiobotocore` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`EKSClient` provides annotations for `session.create_client("eks")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_eks import EKSClient

session = get_session()
async with session.create_client("eks") as client:
    client: EKSClient
    # now client usage is checked by mypy and IDE should provide code completion
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_eks.paginator` module contains type annotations for all
paginators.

```python
from aiobotocore.session import get_session

from types_aiobotocore_eks import EKSClient
from types_aiobotocore_eks.paginator import (
    DescribeAddonVersionsPaginator,
    ListAddonsPaginator,
    ListClustersPaginator,
    ListFargateProfilesPaginator,
    ListIdentityProviderConfigsPaginator,
    ListNodegroupsPaginator,
    ListUpdatesPaginator,
)

session = get_session()
async with session.create_client("eks") as client:
    client: EKSClient

    # Explicit type annotations are optional here
    # Types should be correctly discovered by mypy and IDEs
    describe_addon_versions_paginator: DescribeAddonVersionsPaginator = client.get_paginator(
        "describe_addon_versions"
    )
    list_addons_paginator: ListAddonsPaginator = client.get_paginator("list_addons")
    list_clusters_paginator: ListClustersPaginator = client.get_paginator("list_clusters")
    list_fargate_profiles_paginator: ListFargateProfilesPaginator = client.get_paginator(
        "list_fargate_profiles"
    )
    list_identity_provider_configs_paginator: ListIdentityProviderConfigsPaginator = (
        client.get_paginator("list_identity_provider_configs")
    )
    list_nodegroups_paginator: ListNodegroupsPaginator = client.get_paginator("list_nodegroups")
    list_updates_paginator: ListUpdatesPaginator = client.get_paginator("list_updates")
```

<a id="waiters-annotations"></a>

### Waiters annotations

`types_aiobotocore_eks.waiter` module contains type annotations for all
waiters.

```python
from aiobotocore.session import get_session

from types_aiobotocore_eks.client import EKSClient
from types_aiobotocore_eks.waiter import (
    AddonActiveWaiter,
    AddonDeletedWaiter,
    ClusterActiveWaiter,
    ClusterDeletedWaiter,
    FargateProfileActiveWaiter,
    FargateProfileDeletedWaiter,
    NodegroupActiveWaiter,
    NodegroupDeletedWaiter,
)

session = get_session()
async with session.create_client("eks") as client:
    client: EKSClient

    # Explicit type annotations are optional here
    # Types should be correctly discovered by mypy and IDEs
    addon_active_waiter: AddonActiveWaiter = client.get_waiter("addon_active")
    addon_deleted_waiter: AddonDeletedWaiter = client.get_waiter("addon_deleted")
    cluster_active_waiter: ClusterActiveWaiter = client.get_waiter("cluster_active")
    cluster_deleted_waiter: ClusterDeletedWaiter = client.get_waiter("cluster_deleted")
    fargate_profile_active_waiter: FargateProfileActiveWaiter = client.get_waiter(
        "fargate_profile_active"
    )
    fargate_profile_deleted_waiter: FargateProfileDeletedWaiter = client.get_waiter(
        "fargate_profile_deleted"
    )
    nodegroup_active_waiter: NodegroupActiveWaiter = client.get_waiter("nodegroup_active")
    nodegroup_deleted_waiter: NodegroupDeletedWaiter = client.get_waiter("nodegroup_deleted")
```

<a id="literals"></a>

### Literals

`types_aiobotocore_eks.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_eks.literals import (
    AMITypesType,
    AddonActiveWaiterName,
    AddonDeletedWaiterName,
    AddonIssueCodeType,
    AddonStatusType,
    CapacityTypesType,
    ClusterActiveWaiterName,
    ClusterDeletedWaiterName,
    ClusterStatusType,
    ConnectorConfigProviderType,
    DescribeAddonVersionsPaginatorName,
    ErrorCodeType,
    FargateProfileActiveWaiterName,
    FargateProfileDeletedWaiterName,
    FargateProfileStatusType,
    IpFamilyType,
    ListAddonsPaginatorName,
    ListClustersPaginatorName,
    ListFargateProfilesPaginatorName,
    ListIdentityProviderConfigsPaginatorName,
    ListNodegroupsPaginatorName,
    ListUpdatesPaginatorName,
    LogTypeType,
    NodegroupActiveWaiterName,
    NodegroupDeletedWaiterName,
    NodegroupIssueCodeType,
    NodegroupStatusType,
    ResolveConflictsType,
    TaintEffectType,
    UpdateParamTypeType,
    UpdateStatusType,
    UpdateTypeType,
    configStatusType,
    EKSServiceName,
    ServiceName,
    ResourceServiceName,
    PaginatorName,
    WaiterName,
    RegionName,
)


def check_value(value: AMITypesType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`types_aiobotocore_eks.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_eks.type_defs import (
    AddonIssueTypeDef,
    CompatibilityTypeDef,
    ResponseMetadataTypeDef,
    OidcIdentityProviderConfigRequestTypeDef,
    AutoScalingGroupTypeDef,
    CertificateTypeDef,
    ConnectorConfigResponseTypeDef,
    KubernetesNetworkConfigResponseTypeDef,
    VpcConfigResponseTypeDef,
    ConnectorConfigRequestTypeDef,
    CreateAddonRequestRequestTypeDef,
    KubernetesNetworkConfigRequestTypeDef,
    VpcConfigRequestTypeDef,
    FargateProfileSelectorTypeDef,
    LaunchTemplateSpecificationTypeDef,
    NodegroupScalingConfigTypeDef,
    NodegroupUpdateConfigTypeDef,
    RemoteAccessConfigTypeDef,
    TaintTypeDef,
    DeleteAddonRequestRequestTypeDef,
    DeleteClusterRequestRequestTypeDef,
    DeleteFargateProfileRequestRequestTypeDef,
    DeleteNodegroupRequestRequestTypeDef,
    DeregisterClusterRequestRequestTypeDef,
    WaiterConfigTypeDef,
    DescribeAddonRequestRequestTypeDef,
    PaginatorConfigTypeDef,
    DescribeAddonVersionsRequestRequestTypeDef,
    DescribeClusterRequestRequestTypeDef,
    DescribeFargateProfileRequestRequestTypeDef,
    IdentityProviderConfigTypeDef,
    DescribeNodegroupRequestRequestTypeDef,
    DescribeUpdateRequestRequestTypeDef,
    ProviderTypeDef,
    ErrorDetailTypeDef,
    OidcIdentityProviderConfigTypeDef,
    OIDCTypeDef,
    IssueTypeDef,
    ListAddonsRequestRequestTypeDef,
    ListClustersRequestRequestTypeDef,
    ListFargateProfilesRequestRequestTypeDef,
    ListIdentityProviderConfigsRequestRequestTypeDef,
    ListNodegroupsRequestRequestTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListUpdatesRequestRequestTypeDef,
    LogSetupTypeDef,
    TagResourceRequestRequestTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateAddonRequestRequestTypeDef,
    UpdateClusterVersionRequestRequestTypeDef,
    UpdateLabelsPayloadTypeDef,
    UpdateParamTypeDef,
    AddonHealthTypeDef,
    AddonVersionInfoTypeDef,
    ListAddonsResponseTypeDef,
    ListClustersResponseTypeDef,
    ListFargateProfilesResponseTypeDef,
    ListNodegroupsResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    ListUpdatesResponseTypeDef,
    AssociateIdentityProviderConfigRequestRequestTypeDef,
    NodegroupResourcesTypeDef,
    RegisterClusterRequestRequestTypeDef,
    CreateFargateProfileRequestRequestTypeDef,
    FargateProfileTypeDef,
    UpdateNodegroupVersionRequestRequestTypeDef,
    CreateNodegroupRequestRequestTypeDef,
    UpdateTaintsPayloadTypeDef,
    DescribeAddonRequestAddonActiveWaitTypeDef,
    DescribeAddonRequestAddonDeletedWaitTypeDef,
    DescribeClusterRequestClusterActiveWaitTypeDef,
    DescribeClusterRequestClusterDeletedWaitTypeDef,
    DescribeFargateProfileRequestFargateProfileActiveWaitTypeDef,
    DescribeFargateProfileRequestFargateProfileDeletedWaitTypeDef,
    DescribeNodegroupRequestNodegroupActiveWaitTypeDef,
    DescribeNodegroupRequestNodegroupDeletedWaitTypeDef,
    DescribeAddonVersionsRequestDescribeAddonVersionsPaginateTypeDef,
    ListAddonsRequestListAddonsPaginateTypeDef,
    ListClustersRequestListClustersPaginateTypeDef,
    ListFargateProfilesRequestListFargateProfilesPaginateTypeDef,
    ListIdentityProviderConfigsRequestListIdentityProviderConfigsPaginateTypeDef,
    ListNodegroupsRequestListNodegroupsPaginateTypeDef,
    ListUpdatesRequestListUpdatesPaginateTypeDef,
    DescribeIdentityProviderConfigRequestRequestTypeDef,
    DisassociateIdentityProviderConfigRequestRequestTypeDef,
    ListIdentityProviderConfigsResponseTypeDef,
    EncryptionConfigTypeDef,
    IdentityProviderConfigResponseTypeDef,
    IdentityTypeDef,
    NodegroupHealthTypeDef,
    LoggingTypeDef,
    UpdateTypeDef,
    AddonTypeDef,
    AddonInfoTypeDef,
    CreateFargateProfileResponseTypeDef,
    DeleteFargateProfileResponseTypeDef,
    DescribeFargateProfileResponseTypeDef,
    UpdateNodegroupConfigRequestRequestTypeDef,
    AssociateEncryptionConfigRequestRequestTypeDef,
    DescribeIdentityProviderConfigResponseTypeDef,
    NodegroupTypeDef,
    ClusterTypeDef,
    CreateClusterRequestRequestTypeDef,
    UpdateClusterConfigRequestRequestTypeDef,
    AssociateEncryptionConfigResponseTypeDef,
    AssociateIdentityProviderConfigResponseTypeDef,
    DescribeUpdateResponseTypeDef,
    DisassociateIdentityProviderConfigResponseTypeDef,
    UpdateAddonResponseTypeDef,
    UpdateClusterConfigResponseTypeDef,
    UpdateClusterVersionResponseTypeDef,
    UpdateNodegroupConfigResponseTypeDef,
    UpdateNodegroupVersionResponseTypeDef,
    CreateAddonResponseTypeDef,
    DeleteAddonResponseTypeDef,
    DescribeAddonResponseTypeDef,
    DescribeAddonVersionsResponseTypeDef,
    CreateNodegroupResponseTypeDef,
    DeleteNodegroupResponseTypeDef,
    DescribeNodegroupResponseTypeDef,
    CreateClusterResponseTypeDef,
    DeleteClusterResponseTypeDef,
    DeregisterClusterResponseTypeDef,
    DescribeClusterResponseTypeDef,
    RegisterClusterResponseTypeDef,
)


def get_structure() -> AddonIssueTypeDef:
    return {...}
```

<a id="how-it-works"></a>

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for
`aiobotocore` updates. It delivers a drop-in type annotations for you and makes
sure that:

- All available `aiobotocore` services are covered.
- Each public class and method of every `aiobotocore` service gets valid type
  annotations extracted from the documentation (blame `botocore` docs if types
  are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

<a id="what's-new"></a>

## What's new

<a id="implemented-features"></a>

### Implemented features

- Fully type annotated `boto3`, `botocore` and `aiobotocore` libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.session` calls
- Auto discovery of types for `session.client` and `session.session` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

<a id="latest-changes"></a>

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

<a id="versioning"></a>

## Versioning

`types-aiobotocore-eks` version is the same as related `aiobotocore` version
and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="thank-you"></a>

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

<a id="documentation"></a>

## Documentation

All services type annotations can be found in
[aiobotocore docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_eks/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
